Getting Started
===============

After successfully installing from the guide found at :ref:`install`, we can now try to do some science!

When running matador from the command line for the first time, you will be prompted to create a `.matadorrc` config file. This allows you to point to the MongoDB instance you want to use, or set up default plotting options. Alternatively, you can create your own `.matadorrc` based on the default found under ``matador/config/matadorrc.yml`` on `GitHub <https://github.com/ml-evs/matador/blob/master/matador/config/matadorrc.yml>`_.

For API examples, you should now be able to follow/run the Jupyter notebooks found in the ``examples/``. Some of them will require a MongoDB server accessible from your machine. For some details on how to set this up, please look at the :ref:`MongoDB tutorial <mongo>`. For command-line usage, tutorials should start appearing in due course over at :ref:`examples_index`.
